@@ -32,8 +32,8 @@ def prepare_file_name_saving(
     input. It checks to see if the directory exists, and makes it if not. Then
     it returns the full path of the file.
 
-    :param prefix:str: Used to Specify the folder where the file will be saved.
-    :param file_name:str: Used to Specify the name of the file to be saved.
+    :param prefix:str: Used to specify the folder where the file will be saved.
+    :param file_name:str: Used to specify the name of the file to be saved.
     :return: The full path of the file name.
 
     :doc-author: Julian M. Kleber
@@ -67,7 +67,6 @@ def insert_string_in_file_name(file_name: str, insertion: str, suffix: str) -> s
     root, ext = os.path.splitext(file_name)
 
     if suffix is None and not ext:
-
         raise ValueError(
             "You must either specify an suffix in the file_name or pass an suffix through the\
             suffix argument. For example the file_name could be 'foo.bar' or you pass\
@@ -285,3 +284,19 @@ def convert_str_to_bool(bool_str: str) -> None:
     if bool_str == "False":
         bool_str = False
     return bool_str
+
+
+def attach_slash(raw_string: str) -> str:
+    """The attach_slash function takes a string as input and returns the same
+    string with a slash appended to it. If the input already ends in a slash,
+    then no change is made.
+
+    :param raw_string:str: Used to Specify the type of data that is being passed into the function.
+    :return: A string with a trailing slash.
+
+    :doc-author: Julian M. Kleber
+    """
+
+    if not raw_string.endswith("/"):
+        raw_string += "/"
+    return raw_string
